.. pyXCP documentation master file, created by
   sphinx-quickstart on Sun Mar 18 08:53:54 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to pyXCP's documentation!
=================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   installation
   tutorial
   configuration
   howto
   modules


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
